@@ -52,16 +52,21 @@ void bearing_fill_hbox(GtkWidget *hbox,
   if(!isnan(pos.lat) && !isnan(pos.lon)) {
     gtk_box_pack_start(GTK_BOX(hbox), gtk_image_new_from_pixbuf(
 			       		icon_bearing(refpos, pos)),1,0,0);
-    gtk_box_pack_start_defaults(GTK_BOX(hbox), 
-	       GTK_LABEL_SMALL((char*)pos_get_bearing_str(refpos, pos)));
-    snprintf(str, sizeof(str), _("%.1f°"), 
-	     gpx_pos_get_bearing(refpos, pos));
-    gtk_box_pack_start_defaults(GTK_BOX(hbox), GTK_LABEL_SMALL(str));
-    gpx_pos_get_distance_str(str, sizeof(str), 
-			     refpos, pos, appdata->imperial);
-    gtk_box_pack_start(GTK_BOX(hbox), 
-	     gtk_label_attrib(str, SIZE_SMALL, STRIKETHROUGH_NONE),1,0,0);
 
+    if(refpos.lat && refpos.lon) {
+      gtk_box_pack_start_defaults(GTK_BOX(hbox), 
+		   GTK_LABEL_SMALL((char*)pos_get_bearing_str(refpos, pos)));
+      snprintf(str, sizeof(str), _("%.1f°"), 
+	       gpx_pos_get_bearing(refpos, pos));
+      gtk_box_pack_start_defaults(GTK_BOX(hbox), GTK_LABEL_SMALL(str));
+      gpx_pos_get_distance_str(str, sizeof(str), 
+			     refpos, pos, appdata->imperial);
+      gtk_box_pack_start(GTK_BOX(hbox), 
+	     gtk_label_attrib(str, SIZE_SMALL, STRIKETHROUGH_NONE),1,0,0);
+    } else
+      gtk_box_pack_start(GTK_BOX(hbox), 
+			 gtk_label_attrib(_("(no position)"), 
+			 SIZE_SMALL, STRIKETHROUGH_NONE),1,0,0);
   } else
     gtk_box_pack_start(GTK_BOX(hbox), 
 	   gtk_label_attrib(_("(invalid position in notes)"), 
@@ -262,7 +267,6 @@ static GtkWidget *cache_hint(appdata_t *appdata, cache_t *cache) {
     return html_view(appdata, cache->hint, TRUE, TRUE, NULL, NULL);
 
   /* we can now be sure that we are talking about pain text */
-  /* xyz */
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 
   char *hint = strdup(cache->hint);
@@ -344,7 +348,14 @@ static GtkWidget *cache_wpts(appdata_t *appdata, wpt_t *wpt) {
     if(wpt->desc) {
       GtkTextBuffer *buffer = gtk_text_buffer_new(NULL);
       gtk_text_buffer_set_text(buffer, wpt->desc, strlen(wpt->desc));
+
+#ifndef USE_MAEMO
       GtkWidget *textview = gtk_text_view_new_with_buffer(buffer);
+#else
+      GtkWidget *textview = hildon_text_view_new();
+      hildon_text_view_set_buffer(HILDON_TEXT_VIEW(textview), buffer);
+#endif
+
       gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(textview), GTK_WRAP_WORD);
       gtk_text_view_set_editable(GTK_TEXT_VIEW(textview), FALSE);
       gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(textview), FALSE);
@@ -357,7 +368,12 @@ static GtkWidget *cache_wpts(appdata_t *appdata, wpt_t *wpt) {
     if(wpt->cmt) {
       GtkTextBuffer *buffer = gtk_text_buffer_new(NULL);
       gtk_text_buffer_set_text(buffer, wpt->cmt, strlen(wpt->cmt));
+#ifndef USE_MAEMO
       GtkWidget *textview = gtk_text_view_new_with_buffer(buffer);
+#else
+      GtkWidget *textview = hildon_text_view_new();
+      hildon_text_view_set_buffer(HILDON_TEXT_VIEW(textview), buffer);
+#endif
       gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(textview), GTK_WRAP_WORD);
       gtk_text_view_set_editable(GTK_TEXT_VIEW(textview), FALSE);
       gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(textview), FALSE);
@@ -627,7 +643,7 @@ GtkWidget *cache_view(appdata_t *appdata, cache_t *cache) {
   return notebook;
 }
 
-#ifndef USE_MAEMO 
+#ifndef USE_MAEMO
 void cache_dialog(appdata_t *appdata, cache_t *cache) {
   GtkWidget *dialog = gtk_dialog_new_with_buttons(cache->name, 
 			  GTK_WINDOW(appdata->window),
@@ -646,4 +662,20 @@ void cache_dialog(appdata_t *appdata, cache_t *cache) {
   gtk_dialog_run(GTK_DIALOG(dialog));
   gtk_widget_destroy(dialog);
 }
-#endif
+
+#else
+#ifdef USE_STACKABLE_WINDOW
+void cache_dialog(appdata_t *appdata, cache_t *cache) {
+  GtkWidget *window = hildon_stackable_window_new();
+
+  gtk_window_set_title(GTK_WINDOW(window), cache->name);
+
+  /* create cache visualization widget */
+  gtk_container_add(GTK_CONTAINER(window), 
+		    cache_view(appdata, cache));
+
+  gtk_widget_show_all(window);
+}
+#endif // USE_STACKABLE_WINDOW
+
+#endif // USE_MAEMO
