@@ -3,8 +3,8 @@
 
 #define TAG_STATE  GTK_STATE_PRELIGHT
 
-#define DEFAULT_LAT 49.02833
-#define DEFAULT_LON  8.39042
+// #define DEFAULT_LAT 49.02833
+// #define DEFAULT_LON  8.39042
 
 #ifndef USE_MAEMO
 #define DEFAULT_IMAGE_PATH       "/tmp/gpxview/"
