@@ -500,13 +500,70 @@ void gps_release(appdata_t *appdata) {
 
 #else
 
-#warning "liblocation interface not implemented"
+#warning "liblocation interface not completely implemented"
+
+static void
+location_changed(LocationGPSDevice *device, gps_state_t *gps_state) {
+
+  gps_state->fix = 
+    (device->fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET);
+  
+  if(gps_state->fix) { 
+    gps_state->latitude = device->fix->latitude;
+    gps_state->longitude = device->fix->longitude;
+  }
+}
+
+void gps_init(appdata_t *appdata) {
+  gps_state_t *gps_state = appdata->gps_state = g_new0(gps_state_t, 1);
+
+  printf("GPS init: Using liblocation\n");
+
+  gps_state->device = g_object_new(LOCATION_TYPE_GPS_DEVICE, NULL);  
+  if(!gps_state->device) {
+    printf("Unable to connect to liblocation\n");
+    return;
+  }
+
+  gps_state->idd_changed = 
+    g_signal_connect(gps_state->device, "changed", 
+		     G_CALLBACK(location_changed), gps_state);
+
+}
+
+void gps_release(appdata_t *appdata) {
+  gps_state_t *gps_state = appdata->gps_state;
+  
+  if(!gps_state->device) return;
+  
+  /* Disconnect signal */
+  g_signal_handler_disconnect(gps_state->device, gps_state->idd_changed);
+  
+  g_free(appdata->gps_state);
+  appdata->gps_state = NULL;
+}
+
+pos_t *gps_get_pos(appdata_t *appdata) {   
+  static pos_t pos;
+
+  if(!appdata->use_gps)
+    return NULL;
+
+  gps_state_t *gps_state = appdata->gps_state;
+
+  if(!gps_state->fix)
+    return NULL;
+
+  pos.lat = gps_state->latitude;
+  pos.lon = gps_state->longitude;
+
+  return &pos; 
+}
 
-void gps_init(appdata_t *appdata) {}
-void gps_release(appdata_t *appdata) {}
-pos_t *gps_get_pos(appdata_t *appdata) { return NULL; }
 float gps_get_heading(appdata_t *appdata) { return NAN; }
+
 float gps_get_epe(appdata_t *appdata) { return NAN; }
+
 gps_sat_t *gps_get_sats(appdata_t *appdata) { return NULL; }
 
 
