@@ -141,7 +141,13 @@ struct gps_data_t {
 #include <errno.h>
 #endif
 
+#ifdef ENABLE_LIBLOCATION
+#include <location/location-gps-device.h>
+#include <location/location-gpsd-control.h>
+#endif
+
 typedef struct gps_state {
+#ifndef ENABLE_LIBLOCATION
 #ifdef ENABLE_GPSBT
   gpsbt_t context;
 #endif
@@ -152,6 +158,12 @@ typedef struct gps_state {
   GnomeVFSSocket *socket;
 
   struct gps_data_t gpsdata;
+#else
+  LocationGPSDevice *device;
+  guint idd_changed;
+  gboolean fix, fix3d;
+  double latitude, longitude;
+#endif
 } gps_state_t;
 
 typedef struct {
