@@ -1347,6 +1347,10 @@ float gpx_pos_get_distance(pos_t p1, pos_t p2, int miles) {
 
 void gpx_pos_get_distance_str(char *str, int len, 
 			      pos_t p1, pos_t p2, int mil) {
+  if(!p1.lat && !p1.lon) {
+    snprintf(str, len, "---");
+    return;
+  }
 
   float dist = gpx_pos_get_distance(p1, p2, mil);
   distance_str(str, len, dist, mil);
