@@ -20,6 +20,14 @@
 #ifndef GPXVIEW_H
 #define GPXVIEW_H
 
+#ifdef USE_MAEMO
+#if MAEMO_VERSION_MAJOR < 5
+#define USE_BREAD_CRUMB_TRAIL
+#else
+#define USE_STACKABLE_WINDOW
+#endif
+#endif
+
 #include "config.h"
 
 #include <string.h>
@@ -33,6 +41,7 @@
 
 #ifdef USE_MAEMO
 #include <hildon/hildon-program.h>
+#include <hildon/hildon-text-view.h>
 #include <hildon/hildon-file-chooser-dialog.h>
 #include <hildon/hildon-file-system-model.h>
 #include <hildon/hildon-bread-crumb-trail.h>
@@ -143,6 +152,7 @@ typedef struct {
   gboolean garmin_ign_found;
 
 #ifdef USE_MAEMO
+  gboolean fullscreen;
   pos_t mmpos;                /* position received from Maemo Mapper */
   gboolean mmpos_valid;
 
@@ -162,13 +172,6 @@ typedef struct {
   GtkWidget *menu_import, *menu_export;
   GtkWidget *menu_search;
 
-  /* reference to change this to reflect fullscreen by hard button */
-  /* and the ability to zoom */
-#if MAEMO_VERSION_MAJOR < 5
-  GtkWidget *fullscreen_menu_item;
-#endif
-  GtkWidget *zoomin_menu_item, *zoomout_menu_item;
-
   /* keep track of current "path" in the bread crumb trail */
   gpx_t *cur_gpx;
   cache_t *cur_cache;
