@@ -303,15 +303,6 @@ static void on_destroy_htmlview(GtkWidget *widget, gpointer data) {
   *h = (*h)->next;
   free(tmp);
 
-#ifdef USE_MAEMO
-  /* check if there are no more views left and disable zoom menu */
-  /* entries if there aren't any left */
-  if(context->appdata->window && !context->appdata->html_view) {
-    gtk_widget_set_sensitive(context->appdata->zoomin_menu_item,  FALSE);
-    gtk_widget_set_sensitive(context->appdata->zoomout_menu_item,  FALSE);
-  }
-#endif
-
   load_context_t *load_context = context->load_context;
   while(load_context) {
     printf("found an associated thread\n");
@@ -353,7 +344,10 @@ void html_copy_to_clipboard(appdata_t *appdata) {
   gtk_html_copy(GTK_HTML(appdata->active_buffer));
 }
 
-#ifdef USE_PANNABLE_AREA
+/* panning a gtkhtml view currently doesn't work well */
+#undef PANNABLE_HTML
+
+#ifdef PANNABLE_HTML
 /* eat the button events */
 static gboolean on_button_press(GtkWidget *widget, GdkEventButton *event,
 				gpointer user_data) {
@@ -361,9 +355,6 @@ static gboolean on_button_press(GtkWidget *widget, GdkEventButton *event,
 }
 #endif
 
-/* panning a gtkhtml view currently doesn't work well */
-#undef PANNABLE_HTML
-
 /* the cache descriptions are not valid html and need some surrounding stuff */
 static const char *html_start = "<html><head>"
   "<meta http-equiv=content-type content=\"text/html; charset=UTF-8\">"
@@ -394,14 +385,6 @@ GtkWidget *html_view(appdata_t *appdata, char *text,
     gtk_html_write(GTK_HTML(view), stream, html_end, strlen(html_end));
     gtk_html_end(GTK_HTML(view), stream, GTK_HTML_STREAM_OK);
 
-#ifdef USE_MAEMO
-    /* check if there weren't any views yet and enable zoom menu entries */
-    if(appdata->program && !appdata->html_view) {
-      gtk_widget_set_sensitive(appdata->zoomin_menu_item,  TRUE);
-      gtk_widget_set_sensitive(appdata->zoomout_menu_item,  TRUE);
-    }
-#endif
-
     if(anchor) {
       while(gtk_events_pending())
 	gtk_main_iteration ();
@@ -429,27 +412,18 @@ GtkWidget *html_view(appdata_t *appdata, char *text,
   } else {
     GtkTextBuffer *buffer = gtk_text_buffer_new(NULL);
     gtk_text_buffer_set_text(buffer, text, strlen(text));
+
+#ifndef USE_MAEMO    
     view = gtk_text_view_new_with_buffer(buffer);
+#else
+    view = hildon_text_view_new();
+    hildon_text_view_set_buffer(HILDON_TEXT_VIEW(view), buffer);
+#endif
+
     gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(view), GTK_WRAP_WORD);
     gtk_text_view_set_editable(GTK_TEXT_VIEW(view), FALSE);
     gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(view), FALSE);
 
-#ifdef USE_PANNABLE_AREA
-    /* only the caches description has "scrollwin" enabled since selection */
-    /* is only needed there */
-    if(!scrollwin) {
-      GdkColor color;
-      gdk_color_parse("lightgrey", &color);
-
-      gtk_widget_set_sensitive(GTK_WIDGET(view), FALSE);
-
-      /* settings the widget insensitive also sets its background */
-      /* to the "insesitive" state which makes it pretty inreadable */
-      /* on fremantle. Thus set it to light grey */
-      gtk_widget_modify_base(view, GTK_STATE_INSENSITIVE, &color);
-    }
-#endif
-
     g_signal_connect(G_OBJECT(view), "destroy", 
 		     G_CALLBACK(on_destroy_textview), appdata);
   } 
@@ -463,7 +437,16 @@ GtkWidget *html_view(appdata_t *appdata, char *text,
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW (scrolled_window), 
 		     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_container_add(GTK_CONTAINER(scrolled_window), view);
+
+#if 1
     return scrolled_window;
+#else
+    GtkWidget *fixed = gtk_fixed_new();
+    gtk_fixed_put(GTK_FIXED(fixed), scrolled_window, 0, 0);
+    GtkWidget *tbutton = gtk_toggle_button_new_with_label("sel");
+    gtk_fixed_put(GTK_FIXED(fixed), tbutton, 0, 0);
+    return fixed;
+#endif
 #else
 #ifndef PANNABLE_HTML
   if(is_html) { 
