@@ -35,7 +35,7 @@
 
 extern char *strcasestr (__const char *__haystack, __const char *__needle);
 
-#ifdef USE_MAEMO
+#ifdef USE_BREAD_CRUMB_TRAIL
 static void crumb_add(appdata_t *appdata, char *name, int level, 
 		      gpointer user_data);
 
@@ -46,8 +46,8 @@ enum {
   CRUMB_SEARCH_GPX,
   CRUMB_CACHE,
 };
-
 #endif
+
 /* size of first buffer malloc; start small to exercise grow routines */
 #define	FIRSTSIZE	1
 
@@ -205,7 +205,7 @@ void cachelist_view_onRowActivated(GtkTreeView        *treeview,
   if(gtk_tree_model_get_iter(model, &iter, path)) {
     cache_t *cache;
     gtk_tree_model_get(model, &iter, CACHELIST_COL_DATA, &cache, -1);
-#ifndef USE_MAEMO
+#ifndef USE_BREAD_CRUMB_TRAIL
     cache_dialog(appdata, cache);
 #else
     gtk_container_remove(GTK_CONTAINER(appdata->vbox), appdata->cur_view);
@@ -409,13 +409,6 @@ static GtkWidget *cachelist_create(appdata_t *appdata, gpx_t *gpx,
 
   GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
   
-#ifdef USE_MAEMO
-  /* this is rather slow under maemo, so draw some busy indicator */
-  GtkWidget *animation = 
-    hildon_banner_show_animation(GTK_WIDGET(appdata->window), 
-				 NULL, _("Updating...")); 
-#endif
-
   GtkTreeIter sel_iter;
   gboolean sel_iter_valid = FALSE;
   GtkTreePath *path = NULL; 
@@ -465,20 +458,9 @@ static GtkWidget *cachelist_create(appdata_t *appdata, gpx_t *gpx,
       }
     }
 
-#ifdef USE_MAEMO
-    /* give gtk a chance to update the busy indicator */
-  while(gtk_events_pending())
-    gtk_main_iteration();
-#endif
-
     cache = cache->next;
   }
 
-#ifdef USE_MAEMO
-  /* close the busy indicator */
-  gtk_widget_destroy(animation);
-#endif
-
   gtk_tree_view_set_model(GTK_TREE_VIEW(view), GTK_TREE_MODEL(store));
   g_object_unref(store);
 
@@ -542,14 +524,13 @@ static GtkWidget *cachelist_create(appdata_t *appdata, gpx_t *gpx,
 
 #ifndef USE_MAEMO
 void cachelist_dialog(appdata_t *appdata, gpx_t *gpx) {
-  GtkWidget *dialog;
-
-  dialog = gtk_dialog_new_with_buttons(gpx->name, GTK_WINDOW(appdata->window),
-		       GTK_DIALOG_NO_SEPARATOR | GTK_DIALOG_MODAL | 
-				       GTK_DIALOG_DESTROY_WITH_PARENT,
-		       GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-                       NULL);
-
+  GtkWidget *dialog = 
+    gtk_dialog_new_with_buttons(gpx->name, GTK_WINDOW(appdata->window),
+				GTK_DIALOG_NO_SEPARATOR | GTK_DIALOG_MODAL | 
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+				NULL);
+  
   gtk_window_set_default_size(GTK_WINDOW(dialog), DIALOG_WIDTH, DIALOG_HEIGHT);
 
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), 
@@ -560,6 +541,19 @@ void cachelist_dialog(appdata_t *appdata, gpx_t *gpx) {
   gtk_dialog_run(GTK_DIALOG(dialog));
   gtk_widget_destroy(dialog);
 }
+#else
+#ifdef USE_STACKABLE_WINDOW
+void cachelist_dialog(appdata_t *appdata, gpx_t *gpx) {
+  GtkWidget *window = hildon_stackable_window_new();
+
+  gtk_window_set_title(GTK_WINDOW(window), gpx->name);
+
+  gtk_container_add(GTK_CONTAINER(window), 
+		    cachelist_create(appdata, gpx, NULL));
+
+  gtk_widget_show_all(window);
+}
+#endif
 #endif
 
 /******************** end of cachelist ********************/
@@ -766,7 +760,7 @@ static void gpxlist_view_onRowActivated(GtkTreeView *treeview,
       
 	gpx_busy_dialog_destroy(dialog);
       }
-#ifndef USE_MAEMO
+#ifndef USE_BREAD_CRUMB_TRAIL
       cachelist_dialog(appdata, gpx);
 #else
       gtk_container_remove(GTK_CONTAINER(appdata->vbox), appdata->cur_view);
@@ -1350,7 +1344,7 @@ cb_menu_search(GtkWidget *window, gpointer data) {
 
       printf("Search for %s (flags = %x)...\n", p, appdata->search);
 
-#ifndef USE_MAEMO
+#ifndef USE_BREAD_CRUMB_TRAIL
       found = search_do(appdata, appdata->gpx, p, appdata->search, FALSE);
 
       /* do search result dialog here ... */
@@ -1379,33 +1373,11 @@ cb_menu_search(GtkWidget *window, gpointer data) {
 
 void on_window_destroy (GtkWidget *widget, gpointer data);
 
+#ifndef USE_MAEMO
 static void 
 cb_menu_quit(GtkWidget *window, gpointer data) {
   on_window_destroy(window, data);
 }
-
-#ifdef USE_MAEMO
-#if MAEMO_VERSION_MAJOR < 5
-static void 
-cb_menu_fullscreen(GtkWidget *widget, gpointer data) {
-  appdata_t *appdata = (appdata_t *)data;
-
-  if(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget)))
-    gtk_window_fullscreen(GTK_WINDOW(appdata->window));
-  else
-    gtk_window_unfullscreen(GTK_WINDOW(appdata->window));
-}
-#endif
-
-static void 
-cb_menu_zoomin(GtkWidget *widget, gpointer data) {
-  html_zoom((appdata_t *)data, TRUE);
-}
-
-static void 
-cb_menu_zoomout(GtkWidget *widget, gpointer data) {
-  html_zoom((appdata_t *)data, FALSE);
-}
 #endif
 
 static void 
@@ -1563,35 +1535,6 @@ void menu_create(appdata_t *appdata) {
   gtk_menu_append(GTK_MENU_SHELL(submenu), item);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_paste), appdata);
 
-  /* ----------- view submenu ----------------- */
-
-#ifdef USE_MAEMO
-  item = gtk_menu_item_new_with_label(_("View"));
-  gtk_menu_append(GTK_MENU_SHELL(menu), item);
-  submenu = gtk_menu_new();
-  gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
-
-#if MAEMO_VERSION_MAJOR < 5
-  appdata->fullscreen_menu_item = 
-    item = gtk_check_menu_item_new_with_label( _("Fullscreen") );
-  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
-  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_fullscreen), 
-		   appdata);
-#endif
-
-  appdata->zoomout_menu_item = item = gtk_menu_item_new_with_label( _("Zoom +" ));
-  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
-  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_zoomin), 
-		   appdata);
-  gtk_widget_set_sensitive(item,  FALSE);
-
-  appdata->zoomin_menu_item = item = gtk_menu_item_new_with_label( _("Zoom -") );
-  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
-  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_zoomout), 
-		   appdata);
-  gtk_widget_set_sensitive(item,  FALSE);
-#endif
-
   item = gtk_menu_item_new_with_label( _("Settings...") );
   gtk_menu_append(GTK_MENU_SHELL(menu), item);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_settings), 
@@ -1631,10 +1574,11 @@ void menu_create(appdata_t *appdata) {
   gtk_menu_append(GTK_MENU_SHELL(menu), item);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_about), appdata);
 
-
+#ifndef USE_MAEMO
   item = gtk_menu_item_new_with_label( _("Quit") );
   gtk_menu_append(GTK_MENU_SHELL(menu), item);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_quit), appdata);
+#endif
 
 #ifdef USE_MAEMO
   hildon_window_set_menu(appdata->window, GTK_MENU(menu));
@@ -1733,12 +1677,9 @@ gboolean on_window_key_press(GtkWidget *widget,
 #ifdef HILDON_HARDKEY_FULLSCREEN
   case HILDON_HARDKEY_FULLSCREEN:
     {
-      gboolean fullscreen = !gtk_check_menu_item_get_active(
-	       GTK_CHECK_MENU_ITEM(appdata->fullscreen_menu_item));
-      gtk_check_menu_item_set_active(
-	       GTK_CHECK_MENU_ITEM(appdata->fullscreen_menu_item), fullscreen);
+      appdata->fullscreen = !appdata->fullscreen;
 
-      if(fullscreen)
+      if(appdata->fullscreen)
 	gtk_window_fullscreen(GTK_WINDOW(appdata->window));
       else
 	gtk_window_unfullscreen(GTK_WINDOW(appdata->window));
@@ -1765,7 +1706,7 @@ gboolean on_window_key_press(GtkWidget *widget,
   return handled;
 }
 
-#ifdef USE_MAEMO
+#ifdef USE_BREAD_CRUMB_TRAIL
 typedef struct {
   int level;
   appdata_t *appdata;
@@ -1900,7 +1841,7 @@ static void crumb_add(appdata_t *appdata, char *name, int level,
   hildon_bread_crumb_trail_push_text(HILDON_BREAD_CRUMB_TRAIL(appdata->bct),
 				     name, crumb, (GDestroyNotify)crumb_back);
 }
-#endif // USE_MAEMO
+#endif // USE_BREAD_CRUMB_TRAIL
 
 void main_after_settings_redraw(appdata_t *appdata, int flags) {
 #ifndef USE_MAEMO
@@ -2000,16 +1941,20 @@ int main(int argc, char *argv[]) {
   g_set_application_name("GPXView");
   
   /* Create HildonWindow and set it to HildonProgram */
+#ifdef USE_STACKABLE_WINDOW
+  appdata.window = HILDON_WINDOW(hildon_stackable_window_new());
+#else
   appdata.window = HILDON_WINDOW(hildon_window_new());
+#endif
   hildon_program_add_window(appdata.program, appdata.window);
 #else
   /* Create a Window. */
   appdata.window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title(GTK_WINDOW(appdata.window), "GPXView");
   /* Set a decent default size for the window. */
   gtk_window_set_default_size(GTK_WINDOW(appdata.window), 500, 300);
 #endif
 
+  gtk_window_set_title(GTK_WINDOW(appdata.window), "GPXView");
   g_signal_connect(G_OBJECT(appdata.window), "destroy", 
 		   G_CALLBACK(on_window_destroy), &appdata);
 
@@ -2021,7 +1966,7 @@ int main(int argc, char *argv[]) {
 
   menu_create(&appdata);
 
-#ifdef USE_MAEMO
+#ifdef USE_BREAD_CRUMB_TRAIL
   appdata.bct = hildon_bread_crumb_trail_new();
 
   gtk_box_pack_start(GTK_BOX(appdata.vbox), appdata.bct, FALSE,FALSE,0);
