@@ -580,17 +580,26 @@ GtkWidget *cache_notes(cache_context_t *context) {
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 0);  
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);  
-  
+
+#ifndef USE_PANNABLE_AREA
   GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), 
   				 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+#else
+  GtkWidget *pannable_area = hildon_pannable_area_new();
+#endif
 
   context->notes.buffer = gtk_text_buffer_new(NULL);
 
   if(cache->notes && cache->notes->text)
     gtk_text_buffer_set_text(context->notes.buffer, cache->notes->text, -1);
 
+#ifndef USE_MAEMO
   GtkWidget *view = gtk_text_view_new_with_buffer(context->notes.buffer);
+#else
+  GtkWidget *view = hildon_text_view_new();
+  hildon_text_view_set_buffer(HILDON_TEXT_VIEW(view), context->notes.buffer);
+#endif
 
   gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(view), GTK_WRAP_WORD);
   gtk_text_view_set_editable(GTK_TEXT_VIEW(view), TRUE);
@@ -608,12 +617,16 @@ GtkWidget *cache_notes(cache_context_t *context) {
   g_signal_connect(G_OBJECT(view), "destroy", 
 		   G_CALLBACK(on_destroy_textview), appdata);
 
+#ifndef USE_PANNABLE_AREA
   gtk_container_add(GTK_CONTAINER(scrolled_window), view);
 
   gtk_scrolled_window_set_shadow_type( GTK_SCROLLED_WINDOW(scrolled_window),
 				       GTK_SHADOW_IN);
-
   gtk_box_pack_start(GTK_BOX(vbox), scrolled_window, TRUE, TRUE, 0);
+#else
+  gtk_container_add(GTK_CONTAINER(pannable_area), view);
+  gtk_box_pack_start(GTK_BOX(vbox), pannable_area, TRUE, TRUE, 0);
+#endif
 
   gtk_text_view_place_cursor_onscreen(GTK_TEXT_VIEW(view));
   
